melviewr-package: melviewr: A viewer for MELODIC output and ICA+FIX classification.
Description
The melviewr package allows the user to easily view and classify
MELODIC output for the purposes of later running ICA+FIX. The user
categorizes a component as signal or noise based on its spatial
characteristics as well as its temporal profile. melviewr can then save
a text file of these classifications in the format required by ICA+FIX.
melviewr functions
melviewr